@@ -17,7 +17,7 @@ from reportlab.pdfbase.ttfonts import TTFont, TTFontFace, TTFontFile, TTFOpenFil
                                       FF_SYMBOLIC, FF_NONSYMBOLIC, \
                                       calcChecksum, add32
 from reportlab import rl_config
-from reportlab.lib.utils import getBytesIO, isPy3, uniChr, int2Byte
+from reportlab.lib.utils import getBytesIO, uniChr, int2Byte
 
 def utf8(code):
     "Convert a given UCS character index into UTF-8"
@@ -46,16 +46,16 @@ def show_all_glyphs(fn,fontName='Vera'):
     from reportlab.lib.utils import uniChr
     font = _fonts[fontName]
     doc = c._doc
-    kfunc = font.face.charToGlyph.keys if isPy3 else font.face.charToGlyph.iterkeys
-    for s in kfunc():
+    kfunc = font.face.charToGlyph.keys
+    for s in sorted(list(kfunc())):
         if s<0x10000:
             font.splitString(uniChr(s),doc)
     state = font.state[doc]
     cn = {}
     #print('len(assignments)=%d'%  len(state.assignments))
     nzero = 0
-    ifunc = state.assignments.items if isPy3 else state.assignments.iteritems
-    for code, n in ifunc():
+    ifunc = state.assignments.items
+    for code, n in sorted(list(ifunc())):
         if code==0: nzero += 1
         cn[n] = uniChr(code)
     if nzero>1: print('%s there were %d zero codes' % (fontName,nzero))
@@ -294,7 +294,7 @@ class TTFontTestCase(NearTestCase):
         w3R/aE28KsfY2J+RPNp+j+KaOoCey4h+Dd48b9O5G0v2K7j0AM6s+5WQ/E0wVoK+pA6/3bup7bJf
         CMGjwvxTsr74/f/F95m3TH9x8o0/TU//N+7/D/ScVcA=
         """.encode('latin1')
-        uncompressed = zlib.decompress(getattr(base64,'decodebytes' if isPy3 else 'decodestring')(font))
+        uncompressed = zlib.decompress(base64.decodebytes(font))
         ttf = io.BytesIO(uncompressed)
         setattr(ttf ,"name", "(invisible.ttf)")
         font = TTFont('invisible', ttf)
@@ -309,16 +309,15 @@ class TTFontTestCase(NearTestCase):
         font = TTFont("Vera", "Vera.ttf")
         text = b"".join(utf8(i) for i in range(511))
         allchars = b"".join(int2Byte(i) for i in range(256))
-        if rl_config.reserveTTFNotdef:
-            chunks = [(0, allchars), (1, allchars[1:32] + allchars[33:]), (2, b'\x01')]
-        else:
-            chunks = [(0, allchars), (1, allchars[:32] + allchars[33:])]
+        chunks = [(0, allchars[:0xa0]+b' '+allchars[0xa0:])] + [
+                (1, allchars[1:32] + allchars[33:]) if rl_config.reserveTTFNotdef else
+                (1, allchars[:32] + allchars[33:-1])]
         self.assertEqual(font.splitString(text, doc), chunks)
         # Do it twice
         self.assertEqual(font.splitString(text, doc), chunks)
 
         text = b"".join(utf8(i) for i in range(510, -1, -1))
-        revver = (lambda b: map(int2Byte,reversed(b))) if isPy3 else (lambda b: reversed(list(b)))
+        revver = lambda b: map(int2Byte,reversed(b))
         chunks = [(i[0],b"".join(revver(i[1]))) for i in reversed(chunks)]
         self.assertEqual(font.splitString(text, doc), chunks)
 
